@@ -56,7 +56,6 @@ KInfoCenter::KInfoCenter() : KXmlGuiWindow( 0, Qt::WindowContextHelpButtonHint )
     setCentralWidget(m_cWidget);
 
     QVBoxLayout *cLayout = new QVBoxLayout(m_cWidget);
-    Q_UNUSED(cLayout);
 
     cLayout->setSpacing(0);
     cLayout->setContentsMargins(0, 0, 0, 0);
@@ -103,7 +102,7 @@ KInfoCenter::~KInfoCenter()
     disconnect(m_searchAction, SIGNAL(triggered()),m_searchText, SLOT(setFocus()));
 
     //Buttons
-    disconnect(m_moduleHelpAction, &QAction::triggered,this,&KInfoCenter::helpClickedSlot);
+    disconnect(m_moduleHelpAction, &QAction::triggered, this, &KInfoCenter::helpClickedSlot);
 
     //Menu
     disconnect(m_aboutKcm, &QAction::triggered, this, &KInfoCenter::aboutKcmSlot);
@@ -119,7 +118,7 @@ bool KInfoCenter::eventFilter(QObject *watched, QEvent *event)
 
 void KInfoCenter::createToolBar()
 {
-    KStandardAction::quit(this, SLOT(close()), actionCollection());
+    KStandardAction::quit(this, &KInfoCenter::close, actionCollection());
     KStandardAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), actionCollection());
 
     toolBar()->setMovable(false);
@@ -186,12 +185,18 @@ void KInfoCenter::createMenuFrame()
 
     m_sideMenu = new SidePanel(sideFrame);
     m_sideMenu->installEventFilter(this);
+    connect(m_sideMenu, &SidePanel::clearSearchLine, this, &KInfoCenter::clearSearchLine);
 
     menuLayout->addWidget(m_searchText);
     menuLayout->addWidget(m_sideMenu);
     m_splitter->addWidget(sideFrame);
 }
 
+void KInfoCenter::clearSearchLine()
+{
+    m_searchText->clear();
+}
+
 void KInfoCenter::itemClickedSlot(const KcmTreeItem *item)
 {
 	resetCondition();
@@ -229,7 +234,7 @@ void KInfoCenter::helpClickedSlot()
     // Nicked from Ben, could not use KToolInvocation due to docpath.
     QString docPath = m_contain->helpPath();
 
-    QUrl url("help:/" + docPath );
+    QUrl url(QStringLiteral("help:/") + docPath );
     QProcess::startDetached(QStringLiteral("khelpcenter"), QStringList() << url.url());
 }
 
